{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "uncluster sims",
            "doc": "append feature sequence to each hit line of similarity file\n>add_seq2sims --seq_file --in_sim \n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "add_seq2sims.log",
            "stderr": "add_seq2sims.error",
            "inputs": [
                {
                    "type": "string",
                    "doc": "Output merged sims and seq",
                    "inputBinding": {
                        "prefix": "--out_sim"
                    },
                    "id": "#add_seq2sims.tool.cwl/outName"
                },
                {
                    "type": "File",
                    "doc": "Input tabbed sequence file",
                    "inputBinding": {
                        "prefix": "--seq_file"
                    },
                    "id": "#add_seq2sims.tool.cwl/sequences"
                },
                {
                    "type": "File",
                    "doc": "Input similarity file",
                    "inputBinding": {
                        "prefix": "--in_sim"
                    },
                    "id": "#add_seq2sims.tool.cwl/similarity"
                }
            ],
            "baseCommand": [
                "add_seq2sims"
            ],
            "arguments": [
                {
                    "prefix": "--verbose"
                }
            ],
            "id": "#add_seq2sims.tool.cwl",
            "outputs": [
                {
                    "type": "File",
                    "id": "#add_seq2sims.tool.cwl/error",
                    "outputBinding": {
                        "glob": "add_seq2sims.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#add_seq2sims.tool.cwl/info",
                    "outputBinding": {
                        "glob": "add_seq2sims.log"
                    }
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "Output merged sims and seq file",
                    "outputBinding": {
                        "glob": "$([inputs.outName])"
                    },
                    "id": "#add_seq2sims.tool.cwl/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "GNU cat",
            "doc": "Concatenate FILE(s) to standard output",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "$(inputs.outName)",
            "stderr": "cat.error",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "List of files to concatenate",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#cat.tool.cwl/files"
                },
                {
                    "type": "string",
                    "id": "#cat.tool.cwl/outName"
                }
            ],
            "baseCommand": [
                "cat"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#cat.tool.cwl/error",
                    "outputBinding": {
                        "glob": "cat.error"
                    }
                },
                {
                    "type": "File",
                    "doc": "Concatenated file",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#cat.tool.cwl/output"
                }
            ],
            "id": "#cat.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "index sims by md5",
            "doc": "index m8 format blast file by 2nd column (sorted required)\nreturn: value, seek, length for each record\n>index_sims_file_md5 --in_file <input> --out_file <outName> --md5_num <number>\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "index_sims_file_md5.log",
            "stderr": "index_sims_file_md5.error",
            "inputs": [
                {
                    "type": "File",
                    "doc": "Input similarity blast-m8 file",
                    "inputBinding": {
                        "prefix": "--in_file"
                    },
                    "id": "#index_sims_file_md5.tool.cwl/input"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Number of chunks to load in memory at once before processing, default is 5000",
                    "default": 5000,
                    "inputBinding": {
                        "prefix": "--md5_num"
                    },
                    "id": "#index_sims_file_md5.tool.cwl/number"
                },
                {
                    "type": "string",
                    "doc": "Output index",
                    "inputBinding": {
                        "prefix": "--out_file"
                    },
                    "id": "#index_sims_file_md5.tool.cwl/outName"
                }
            ],
            "baseCommand": [
                "index_sims_file_md5"
            ],
            "arguments": [
                {
                    "valueFrom": "--verbose"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#index_sims_file_md5.tool.cwl/error",
                    "outputBinding": {
                        "glob": "index_sims_file_md5.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#index_sims_file_md5.tool.cwl/info",
                    "outputBinding": {
                        "glob": "index_sims_file_md5.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "Output index file",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#index_sims_file_md5.tool.cwl/output"
                }
            ],
            "id": "#index_sims_file_md5.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "seqUtil",
            "doc": "Utility tool for various sequence file transformations.\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "seqUtil.log",
            "stderr": "seqUtil.error",
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Return fasta with each sequence truncated to 1024 bps",
                    "inputBinding": {
                        "prefix": "--bowtie_truncate"
                    },
                    "id": "#seqUtil.tool.cwl/bowtieTruncate"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Transform fasta to tabbed",
                    "inputBinding": {
                        "prefix": "--fasta2tab"
                    },
                    "id": "#seqUtil.tool.cwl/fasta2tab"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Transform fastq to fasta",
                    "inputBinding": {
                        "prefix": "--fastq2fasta"
                    },
                    "id": "#seqUtil.tool.cwl/fastq2fasta"
                },
                {
                    "type": "string",
                    "doc": "Output sequence file",
                    "inputBinding": {
                        "prefix": "--output"
                    },
                    "id": "#seqUtil.tool.cwl/output"
                },
                {
                    "type": "File",
                    "doc": "Input sequence file",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#seqUtil.tool.cwl/sequences"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Sort fasta file by ID",
                    "inputBinding": {
                        "prefix": "--sortbyid"
                    },
                    "id": "#seqUtil.tool.cwl/sortbyid"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Transform fasta to ID list, sorted by ID",
                    "inputBinding": {
                        "prefix": "--sortbyid2id"
                    },
                    "id": "#seqUtil.tool.cwl/sortbyid2id"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Transform fasta to tabbed, sorted by ID",
                    "inputBinding": {
                        "prefix": "--sortbyid2tab"
                    },
                    "id": "#seqUtil.tool.cwl/sortbyid2tab"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "List of sequences to subset input by, required with subsetSeqs option",
                    "inputBinding": {
                        "prefix": "--list"
                    },
                    "id": "#seqUtil.tool.cwl/subsetList"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Return fasta with each sequence truncated to 1024 bps",
                    "inputBinding": {
                        "prefix": "--subset_seqs"
                    },
                    "id": "#seqUtil.tool.cwl/subsetSeqs"
                }
            ],
            "baseCommand": [
                "seqUtil"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#seqUtil.tool.cwl/error",
                    "outputBinding": {
                        "glob": "seqUtil.error"
                    }
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#seqUtil.tool.cwl/file"
                },
                {
                    "type": "File",
                    "id": "#seqUtil.tool.cwl/info",
                    "outputBinding": {
                        "glob": "seqUtil.log"
                    }
                }
            ],
            "id": "#seqUtil.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "GNU sort",
            "doc": "sort text file base on given field(s)",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "sort.log",
            "stderr": "sort.error",
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "use SEP instead of non-blank to blank transition, default is tab",
                    "inputBinding": {
                        "prefix": "-t",
                        "valueFrom": "$(\"\\u0009\")"
                    },
                    "id": "#sort.tool.cwl/field"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "Files to sort",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#sort.tool.cwl/input"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-k"
                        }
                    },
                    "doc": "start a key at POS1, end it at POS2 (origin 1)",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#sort.tool.cwl/key"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "merge only, the input files are assumed to be pre-sorted",
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "id": "#sort.tool.cwl/merge"
                },
                {
                    "type": "string",
                    "doc": "write result to FILE instead of standard output",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#sort.tool.cwl/outName"
                }
            ],
            "baseCommand": [
                "sort"
            ],
            "arguments": [
                {
                    "prefix": "-T",
                    "valueFrom": "$(runtime.tmpdir)"
                },
                {
                    "prefix": "-S",
                    "valueFrom": "$(runtime.ram)M"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#sort.tool.cwl/error",
                    "outputBinding": {
                        "glob": "sort.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#sort.tool.cwl/info",
                    "outputBinding": {
                        "glob": "sort.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "The sorted file",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#sort.tool.cwl/output"
                }
            ],
            "id": "#sort.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "uncluster sims",
            "doc": "expand out similarity file (blast m8) by turning each cluster seed hit into a hit per cluster member\n>uncluster_sims.py <input> <outName> --cfile <cluster> --position <position>\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "uncluster_sims.log",
            "stderr": "uncluster_sims.error",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "-c"
                        }
                    },
                    "doc": "Input cluster mapping files",
                    "id": "#uncluster_sims.tool.cwl/clustMap"
                },
                {
                    "type": "string",
                    "doc": "Output unclustered similarity",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#uncluster_sims.tool.cwl/outName"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Column position of query in sims file, default is 1",
                    "default": 1,
                    "inputBinding": {
                        "prefix": "--position"
                    },
                    "id": "#uncluster_sims.tool.cwl/position"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "-i"
                        }
                    },
                    "doc": "Input similarity hit files",
                    "id": "#uncluster_sims.tool.cwl/simHit"
                }
            ],
            "baseCommand": [
                "uncluster_sims.py"
            ],
            "arguments": [
                {
                    "valueFrom": "--verbose"
                },
                {
                    "prefix": "--db",
                    "valueFrom": "$(runtime.tmpdir)"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#uncluster_sims.tool.cwl/error",
                    "outputBinding": {
                        "glob": "uncluster_sims.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#uncluster_sims.tool.cwl/info",
                    "outputBinding": {
                        "glob": "uncluster_sims.log"
                    }
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "Output unclustered similarity file",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#uncluster_sims.tool.cwl/output"
                }
            ],
            "id": "#uncluster_sims.tool.cwl"
        },
        {
            "class": "Workflow",
            "label": "index sim seq",
            "doc": "create sorted / filtered similarity file with feature sequences, and index by md5",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/clustMaps"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/featureSeqs"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/filterSims"
                },
                {
                    "type": "string",
                    "id": "#main/jobid"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/indexSimSeq/output",
                    "id": "#main/indexOut"
                },
                {
                    "type": "File",
                    "outputSource": "#main/sortSimSeq/output",
                    "id": "#main/simSeqOut"
                }
            ],
            "steps": [
                {
                    "run": "#add_seq2sims.tool.cwl",
                    "in": [
                        {
                            "source": "#main/sortSims/output",
                            "valueFrom": "$(self.basename).seq",
                            "id": "#main/addSeq2Sim/outName"
                        },
                        {
                            "source": "#main/sortSeqs/file",
                            "id": "#main/addSeq2Sim/sequences"
                        },
                        {
                            "source": "#main/sortSims/output",
                            "id": "#main/addSeq2Sim/similarity"
                        }
                    ],
                    "out": [
                        "#main/addSeq2Sim/output"
                    ],
                    "id": "#main/addSeq2Sim"
                },
                {
                    "run": "#cat.tool.cwl",
                    "in": [
                        {
                            "source": "#main/featureSeqs",
                            "id": "#main/catSeqs/files"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).feature.seqs",
                            "id": "#main/catSeqs/outName"
                        }
                    ],
                    "out": [
                        "#main/catSeqs/output"
                    ],
                    "id": "#main/catSeqs"
                },
                {
                    "run": "#index_sims_file_md5.tool.cwl",
                    "in": [
                        {
                            "source": "#main/sortSimSeq/output",
                            "id": "#main/indexSimSeq/input"
                        },
                        {
                            "source": "#main/sortSimSeq/output",
                            "valueFrom": "$(self.basename).index",
                            "id": "#main/indexSimSeq/outName"
                        }
                    ],
                    "out": [
                        "#main/indexSimSeq/output"
                    ],
                    "id": "#main/indexSimSeq"
                },
                {
                    "run": "#seqUtil.tool.cwl",
                    "in": [
                        {
                            "source": "#main/catSeqs/output",
                            "valueFrom": "$(self.basename).sort.tab",
                            "id": "#main/sortSeqs/output"
                        },
                        {
                            "source": "#main/catSeqs/output",
                            "id": "#main/sortSeqs/sequences"
                        },
                        {
                            "default": true,
                            "id": "#main/sortSeqs/sortbyid2tab"
                        }
                    ],
                    "out": [
                        "#main/sortSeqs/file"
                    ],
                    "id": "#main/sortSeqs"
                },
                {
                    "run": "#sort.tool.cwl",
                    "in": [
                        {
                            "source": "#main/addSeq2Sim/output",
                            "id": "#main/sortSimSeq/input"
                        },
                        {
                            "valueFrom": "$([\"2,2\"])",
                            "id": "#main/sortSimSeq/key"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self[0]).700.annotation.sims.filter.seq",
                            "id": "#main/sortSimSeq/outName"
                        }
                    ],
                    "out": [
                        "#main/sortSimSeq/output"
                    ],
                    "id": "#main/sortSimSeq"
                },
                {
                    "run": "#sort.tool.cwl",
                    "in": [
                        {
                            "source": "#main/unclusterSims/output",
                            "id": "#main/sortSims/input"
                        },
                        {
                            "valueFrom": "$([\"1,1\"])",
                            "id": "#main/sortSims/key"
                        },
                        {
                            "source": "#main/unclusterSims/output",
                            "valueFrom": "$(self[0].basename).sort",
                            "id": "#main/sortSims/outName"
                        }
                    ],
                    "out": [
                        "#main/sortSims/output"
                    ],
                    "id": "#main/sortSims"
                },
                {
                    "run": "#uncluster_sims.tool.cwl",
                    "in": [
                        {
                            "source": "#main/clustMaps",
                            "id": "#main/unclusterSims/clustMap"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).uncluster.sims",
                            "id": "#main/unclusterSims/outName"
                        },
                        {
                            "source": "#main/filterSims",
                            "id": "#main/unclusterSims/simHit"
                        }
                    ],
                    "out": [
                        "#main/unclusterSims/output"
                    ],
                    "id": "#main/unclusterSims"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
